#######
Stylish
#######

Style transfer using deep neural network.

**********
References
**********

This implementation is based off of a combination of:

- `A Neural Algorithm of Artistic Style <https://arxiv.org/abs/1508.06576>`_ by
  Gatys et al. (2015)
- `Perceptual Losses for Real-Time Style Transfer and Super-Resolution
  <https://arxiv.org/abs/1603.08155>`_ by Johnson et al. (2016)
- `Instance Normalization: The Missing Ingredient for Fast Stylization
  <https://arxiv.org/abs/1607.08022>`_ by Ulyanov et al. (2017)

The project borrow some logic from Logan Engstrom's `Fast Style Transfer
<https://github.com/lengstrom/fast-style-transfer>`_ and Justin Johnson's
`Fast Neural Style <https://github.com/jcjohnson/fast-neural-style>`_.

*************
Documentation
*************

Full documentation, including installation and setup guides, can be found at
http://stylish.readthedocs.io/en/stable/
